#!/bin/sh
for i in . tests; do
  if [ -e ${i}/functions.sh ]; then
    . ${i}/functions.sh 
  fi
done
if [ -z "${functions_found}" ]; then
  echo "could not find functions.sh"
   exit 1
fi

answer powell.fee "0.000011 9.106146"
exitifwrong $?

answerzero rosenbrock.fee
exitifwrong $?
